Learn R Programming

googleVis (version 0.5.2)

gvisGauge: Google Gauge with R googleChartName <- "gauge" gvisChartName <- "gvisGauge"

Usage

gvisGauge(data, labelvar = "", numvar = "", options = list(), chartid)

Arguments

data
a data.frame to be displayed as a gauge
labelvar
name of the character column which contains the category labels for the slice labels.
numvar
a vector of column names of the numerical variables of the slice values.
options
list of configuration options, see: [results=rd]{gsub("CHARTNAME", googleChartName, readLines(file.path(".", "inst", "mansections", "GoogleChartToolsURLConfigOptions.txt")))}

[results=rd]{paste(readLines(file.path(".", "inst", "ma